@@ -40,10 +40,8 @@ Traceback (most recent call last):
 ValueError: css color 'pcmyka(100,0,0,0)' has wrong number of components
 '''
 import math, re, functools
-from reportlab import isPy3, cmp
 from reportlab.lib.rl_accel import fp_str
 from reportlab.lib.utils import asNative, isStr, rl_safe_eval
-import collections
 from ast import literal_eval
 
 class Color:
@@ -63,6 +61,7 @@ class Color:
     @property
     def __key__(self):
         '''simple comparison by component; cmyk != color ever
+        >>> from reportlab import cmp
         >>> cmp(Color(0,0,0),None)
         -1
         >>> cmp(Color(0,0,0),black)
@@ -147,7 +146,7 @@ class Color:
     @property
     def normalizedAlpha(self):
         return self.alpha
-if isPy3: Color = functools.total_ordering(Color)
+Color = functools.total_ordering(Color)
 
 def opaqueColor(c):
     '''utility to check we have a color that's not fully transparent'''
@@ -1025,7 +1024,7 @@ def _enforceRGB(c):
     return tc
 
 def _chooseEnforceColorSpace(enforceColorSpace):
-    if enforceColorSpace is not None and not isinstance(enforceColorSpace, collections.Callable):
+    if enforceColorSpace is not None and not callable(enforceColorSpace):
         if isinstance(enforceColorSpace,str): enforceColorSpace=enforceColorSpace.upper()
         if enforceColorSpace=='CMYK':
             enforceColorSpace = _enforceCMYK
